@@ -1,59 +1,59 @@
 $VAR1 = {
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'admin' => {
-                       'password' => 'testpass'
+          'defaultAction' => 'ShowDatabases',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'files' => {
+                       'chmod' => '0755',
+                       'group' => 'lze',
+                       'owner' => 'lze'
                      },
+          'cgi' => {
+                     'cookiePath' => '/',
+                     'style' => 'mysql',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'serverName' => 'http://localhost',
+                     'title' => 'MySQL::Admin',
+                     'expires' => '+1y',
+                     'bin' => '/var/www/cgi-bin'
+                   },
+          'uploads' => {
+                         'right' => 2,
+                         'path' => '/var/www/htdocs//download',
+                         'enabled' => 1,
+                         'maxlength' => '2100000000000000',
+                         'chmod' => 438
+                       },
+          'saveTranslate' => '0',
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'version' => '0.98',
+          'mod' => 'n',
           'htmlright' => '2',
-          'language' => 'en',
           'news' => {
                       'right' => 5,
                       'captcha' => 3,
                       'messages' => '5'
                     },
-          'session' => '/var/www/cgi-bin/config/session.pl',
           'floodtime' => 10,
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'tree' => {
-                      'links' => '/var/www/cgi-bin/config/links.pl',
-                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
-                    },
-          'files' => {
-                       'owner' => 'lze',
-                       'chmod' => '0755',
-                       'group' => 'lze'
-                     },
-          'cgi' => {
-                     'bin' => '/var/www/cgi-bin',
-                     'serverName' => 'http://localhost',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'cookiePath' => '/',
-                     'expires' => '+1y',
-                     'title' => 'MySQL::Admin',
-                     'style' => 'mysql'
-                   },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
           'database' => {
-                          'host' => 'localhost',
-                          'user' => 'root',
-                          'password' => '',
-                          'CurrentUser' => 'root',
-                          'CurrentPass' => '',
+                          'name' => 'MySQLAdmin',
                           'CurrentHost' => 'localhost',
                           'CurrentDb' => 'MySQLAdmin',
-                          'name' => 'MySQLAdmin'
+                          'password' => '',
+                          'CurrentUser' => 'root',
+                          'host' => 'localhost',
+                          'user' => 'root',
+                          'CurrentPass' => ''
                         },
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'mod' => 'n',
+          'language' => 'en',
           'size' => '16',
-          'version' => '0.97',
-          'uploads' => {
-                         'chmod' => 438,
-                         'right' => 2,
-                         'enabled' => 1,
-                         'path' => '/var/www/htdocs//download',
-                         'maxlength' => '2100000000000000'
-                       },
-          'saveTranslate' => '0',
-          'defaultAction' => 'ShowDatabases'
+          'admin' => {
+                       'password' => 'testpass'
+                     },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'tree' => {
+                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
+                      'links' => '/var/www/cgi-bin/config/links.pl'
+                    }
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
