@@ -228,10 +228,9 @@ $VAR1 = {
         'editmysqluserrights' => 'Benutzerrechte',
         'showrights'          => 'Rechte',
         'selected'            => 'Alle auswählen',
-        'key_name'            => 'Key Name',
+        'key_name'            => 'Schlüssel',
         'newentry'            => 'Neuer Eintrag',
         't_regtext'           => 'Registrieren',
-        'test'                => 'test',
         'choosefile'          => 'Datei auswählen',
         'login'               => 'Anmelden',
         'gbook_body'          => 'Erstelle Deine Nachricht.',
@@ -296,7 +295,7 @@ $VAR1 = {
     },
     'en' => {
         'createdatabase'     => 'New Database',
-        'wrong_captcha_text' => 'wrong_captcha_text',
+        'wrong_captcha_text' => 'Wrong Captcha',
         'maxlength'          => 'Maxlength',
         'changeengine'       => 'Change Engine',
         'newsperpage'        => 'newsperpage',
