@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 use CGI::Carp qw(fatalsToBrowser);
-use lib qw(../lib);
+use lib qw(lib);
 use MySQL::Admin qw(:all);
 use strict;
 init();
